Date: 07 24, 2001 8:32:35 AM

# or

## Purpose

Check action that succeeds if any of the rule elements from number1 to number2 has matched an actual node. Meaningful only if this is a range of optional rule elements.

## Syntax

or(number1, number1)

## Returns

## Remarks

This action is just a sample. As Text Analysis International™ develops its generic analyzer, more CHECK Actions will be implemented.

## Example

## See Also

succeed, fail, CHECK Actions